TrackedModel

Struct TrackedModel 

pub struct TrackedModel<T> { /* private fields */ }
A model instance with explicit “fields set” tracking.

Implementations

Source

impl<T> TrackedModel<T>

pub const fn new(inner: T, fields_set: FieldsSet) -> TrackedModel<T>

Wrap an instance and an explicit FieldsSet.

pub const fn inner(&self) -> &T

Borrow the wrapped instance.

pub fn inner_mut(&mut self) -> &mut T

Mutably borrow the wrapped instance.

pub fn into_inner(self) -> T

Consume and return the wrapped instance.

pub const fn fields_set(&self) -> &FieldsSet

Access the explicit fields-set bitset.

Source

impl<T> TrackedModel<T>
where T: Model,

pub fn all_fields_set(inner: T) -> TrackedModel<T>

Wrap an instance and mark all model fields as set.

pub fn from_explicit_field_names(inner: T, names: &[&str]) -> TrackedModel<T>

Wrap an instance, marking only the provided field names as “set”.

Field names must match FieldInfo.name values (post-alias).

Source

impl<T> TrackedModel<T>
where T: Model + Serialize,

pub fn sql_model_dump(&self, options: DumpOptions) -> Result<Value, Error>

Model-aware dump with correct exclude_unset semantics.

This mirrors SqlModelDump::sql_model_dump, but supports exclude_unset by consulting the stored FieldsSet.

pub fn sql_model_dump_json(&self) -> Result<String, Error>

pub fn sql_model_dump_json_pretty(&self) -> Result<String, Error>

pub fn sql_model_dump_json_with_options( &self, options: DumpOptions, ) -> Result<String, Error>