pub struct TrackedModel<T> { /* private fields */ }Expand description
A model instance with explicit “fields set” tracking.
Implementations
Sourceimpl<T> TrackedModel<T>
impl<T> TrackedModel<T>
Sourcepub const fn new(inner: T, fields_set: FieldsSet) -> TrackedModel<T>
pub const fn new(inner: T, fields_set: FieldsSet) -> TrackedModel<T>
Wrap an instance and an explicit FieldsSet.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consume and return the wrapped instance.
Sourcepub const fn fields_set(&self) -> &FieldsSet
pub const fn fields_set(&self) -> &FieldsSet
Access the explicit fields-set bitset.
Sourceimpl<T> TrackedModel<T>where
T: Model,
impl<T> TrackedModel<T>where
T: Model,
Sourcepub fn all_fields_set(inner: T) -> TrackedModel<T>
pub fn all_fields_set(inner: T) -> TrackedModel<T>
Wrap an instance and mark all model fields as set.
Sourcepub fn from_explicit_field_names(inner: T, names: &[&str]) -> TrackedModel<T>
pub fn from_explicit_field_names(inner: T, names: &[&str]) -> TrackedModel<T>
Wrap an instance, marking only the provided field names as “set”.
Field names must match FieldInfo.name values (post-alias).
Sourceimpl<T> TrackedModel<T>
impl<T> TrackedModel<T>
Sourcepub fn sql_model_dump(&self, options: DumpOptions) -> Result<Value, Error>
pub fn sql_model_dump(&self, options: DumpOptions) -> Result<Value, Error>
Model-aware dump with correct exclude_unset semantics.
This mirrors SqlModelDump::sql_model_dump, but supports exclude_unset
by consulting the stored FieldsSet.
pub fn sql_model_dump_json(&self) -> Result<String, Error>
pub fn sql_model_dump_json_pretty(&self) -> Result<String, Error>
pub fn sql_model_dump_json_with_options( &self, options: DumpOptions, ) -> Result<String, Error>